
function[]=Fig2_MKModelMyModel()
%%----[]=Fig2_MKModelMyModel()-----
%%----Plot Fig.2 in Dag Myrhaug (2012) and Marginal cdf of xiMK from
%%----derived LH83 model
clc
clear all
close all
global colorSig;
global ha;
global hpNum;
global mu;

mu=[0.1 0.3 0.504 0.6];

hpNum=zeros(length(mu)+1,1);
figure(1);
ha=gca;

colorSig=['r','g','b','k'];
funFig2MyModel();
funFig2MKModel();
postprocess();


function[]=funFig2MKModel()
global hpNum;
global xiMK;
global mu;

xiMK=0.002:0.002:3.002;

%%******************************
%%--Marginal CDF of xi rather than the joint
%%--CDF of xi and h (P(xi,h))
%%--TMR4235 Stochastic Theory of Sea Loads Page 2.26
%%--Figure 2.11 Illustrations of Joint,Marginal and Conditional Probability
%%--Density Functions
%%******************************

%%--- h should be less than 9.2580 for parametric model
%%--- determined by Dag Myrhaug(2012), Eq.(5)
%%---The number of elements in xi vector should be odd in order to use
%%----Simpson method
xi = 0.3- 2* 0.002:0.002:3;
[cdfXiMK ] = MF12cdfXiMK(xi);
y=log(-log(1-cdfXiMK));
x=log(xi(3:2:end));
hpNum(length(mu)+1,1)=plot(x,y,'m-','LineWidth',2);
hold on;

function[]=funFig2MyModel()
global xiMK;
global mu;
global hpNum;
global colorSig;

xiMK=0.002:0.002:3.002;

cdfXi=zeros(length(xiMK)-1,length(mu));
%%----Used for Composite Simpson Method----
NN = (length(xiMK) - 1)/2;
cdfXiSp=zeros(NN,length(mu));
%%----Used for Composite Simpson Method----
for mm=1:1:length(mu)

for i = 1:1:length(xiMK)
pdfXi(i,1) = integral(@(hMK)pdfxiMKhMK(xiMK(i),hMK,mu(mm)),0,inf);
end

for i = 2:1:length(xiMK)
cdfXi(i-1,mm) = trapz(xiMK(1:i),pdfXi(1:i,1));
end

%%----Assign value to variable in specified workspace
assignin('base','cdfXi',cdfXi);
%%----Assign value to variable in specified workspace

%%----Composite Simpson Method-----
%%---Validate againt examples in Pages 204 and 208 given by
%%---R. L. Burden and J. D. Faires, Numerical Analysis, 9th edition,
%%---Brooks-Cole, 2010. ISBN-13: 978-0-538-73351-9; ISBN-10: 0-538-73351-9
dxiMK = xiMK(2) - xiMK(1);
for i = 1:1:NN
    cdfXiSp(i,mm) = dxiMK/3 * (pdfXi(1,1) + pdfXi(2*i+1,1) + ...
        2*sum(pdfXi(3:2:2*i-1)) + 4*sum(pdfXi(2:2:2*i,1)) );
end

%%----Assign value to variable in specified workspace
assignin('base','cdfXiSp',cdfXiSp);
%%----Assign value to variable in specified workspace

%%----Composite Simpson Method-----
%%---Validate againt examples in Pages 204 and 208 given by
%%---R. L. Burden and J. D. Faires, Numerical Analysis, 9th edition,
%%---Brooks-Cole, 2010. ISBN-13: 978-0-538-73351-9; ISBN-10: 0-538-73351-9
%%----Composite Simpson Method-----



y=log(-log(1-cdfXi(:,mm)));
x=log(xiMK(2:1:end));

y=log(-log(1-cdfXiSp(:,mm)));
x=log(xiMK(3:2:end));
hpNum(mm,1)=plot(x,y,'-','LineWidth',2,'Color',colorSig(mm));
hold on;
end

function []=postprocess()
%%**** Necessary to alter row vector into column vector due to cellstr
% xStr=cellstr(num2str(Eta(2:end)'));
global mu;
global hpNum;
global ha;
ylim(ha,[log(-log(1-1e-7))  log(-log(1-0.99999))]);
xlim(ha,[log(0.3) log(3)]);
xValue=[0.3 0.5 0.7 1 1.2 1.5 2 2.5 3 3.5 4 4.5 5 5.5 50];
xCor=log(xValue);
xStr=cellstr(num2str(xValue',12));
yValue=[ 1e-7 1e-6 1e-4 0.001 0.01 0.1  0.5  0.9   0.9999 ];
yCor=log(-log(1-(yValue)));
yStr=cellstr(num2str(yValue',12));

set(gca,'XTick',xCor);
set(gca,'YTick',yCor);
set(gca,'XTickLabel',xStr);
set(gca,'YTickLabel',yStr);


headCell=cell(length(mu),1);
for i=1:1:length(mu)
    headCell{i,1}='\upsilon = ';
end
charMu=num2str(mu');
strMu=cellstr(charMu);
cellLeg=strcat(headCell,strMu);
cellLeg=vertcat(cellLeg,'MF12');
legend(hpNum,cellLeg,'Location','SouthEast','FontSize',30);

xlabel('$$\hat{\xi}_{MK}$$','interpreter','latex','FontSize',30);
ylabel('P($\hat{\xi}_{MK}$)','interpreter','latex','FontSize',30);
title('Marginal Distribution $ P(\hat{\xi}_{MK})$ versus $\hat{\xi}_{MK}$ in Weibull-scale',...
    'Interpreter','Latex','FontSize',30);
set(gca,'FontSize',30);
%%**** Necessary to alter row vector into column vector due to cellstr
