function [hMK,Rv,cdfRH,ExpRH,cdfExp] = MF12Fig17()
%%----[hMK,Rv,cdfRH,ExpRH,cdfExp] = MF12Fig17()----
%%----Calculate cdf of runup given hMK, expected value E(R|hMK) as well as
%%----its probability
%%----Enlightened by Eqs.(9),(11) and 13 in Dag Myrhaug (2012)

hMK = [ 0.25 0.5 1 1.4 2.1];
Rv = 0.002:0.002:10;
K = 1;
Hs=7.5;        %% significant wave height
Hrms=0.714*Hs;
Tp=9.5;        %% peak period
Tz=Tp/1.22;    %% average zero crossing period
g=9.81;
Sm=Hs/(g*Tz^2/(2*pi));
Srms=0.7*Sm;   %% rms value of wave steepness
mslope=0.1;    %% slope
xirms=mslope/sqrt(Srms);
cdfRH = zeros(length(hMK),length(Rv));
ExpRH = zeros(length(hMK),1);
cdfExp = zeros(length(hMK),1);
for nn = 1:1:length(hMK)
    for kk = 1:1:length(Rv)
        [cdfRH(nn,kk),muR,sigmaR] = funR_H(hMK(nn),Rv(kk),K,xirms,Hrms);
    end
    ExpRH(nn) = exp(muR + 1/2 * sigmaR);
    [~,col] = min(abs(Rv - ExpRH(nn)));
    
    cdfExp(nn) = cdfRH(nn,col);
    
end

    function [cdfRH,muR,sigmaR] = funR_H(h,Rv,K,xirms,Hrms)
        
        sigmaS = - 0.15 * atan( 1.75 * ( h - 1.2) ) + 0.225; %% Eq.(5)
        sigmaXi = 1/4 * sigmaS; %% Eq.(10)
        sigmaR = sigmaXi;
        [m,n] = size(h);
        muR = zeros(m,n);
        
        for i = 1:1:m
            for k = 1:1:n
                if h(i,k) <= 1.7
                    mus = 0.558 * h(i,k)^2 - 1.021 * h(i,k) + 0.096;%% Eq.(4)
                    
                else if h(i,k) > 1.7
                        mus = 0.25 * atan( 4 * ( h(i,k) - 1.7) ) - 0.027; %% Eq.(4)
                    end
                end
                
                muR(i,k) = - mus /2 + log( K * xirms * Hrms * h);
                x = (log(Rv) - muR(i,k)) / sqrt(sigmaR); %% Eq.(11)
                cdfRH = normcdf(x,0,1);
            end
            
        end
        
        
        
    end

end