function [cdfXiMK] = MF12cdfXiMK(xiMK)
%%---[cdfXiMK] = MF12cdfXiMK(xiMK)----
%%---Marginal cdf of xiMK from Eq.(8) given in Dag Myrhaug (2012)

   hMax = pi /2 / 1.75  + 1.20 - 1e-5; %% Determined by Eq.(5)
   mm = length(xiMK);
   if mod(mm-1,2) ~=0
       error('MF12cdfXiMK:argChk','For the purpose of using Simpson Method, the number of elements in xiMK should be odd');
   end
   pdfXi = zeros(mm,1);
   for ii = 1:1:mm
      pdfXi(ii,1) = integral(@(hMK)(funH(hMK) .* funXi_H(hMK,xiMK(ii)) ), 0,hMax);
   end
   
   dXi = xiMK(2) - xiMK(1);
   cdfXiMK = zeros((mm-1)/2,1);
   for kk = 1:1:(mm-1)/2
       cdfXiMK(kk,1) = dXi/3 * ( pdfXi(1) + 4*sum(pdfXi(2:2:2*kk)) ...
           + 2*sum(pdfXi(3:2:2*kk-1)) + pdfXi(2*kk+1) );
   end
% cdfXiMK = trapz(xiMK,pdfXi);
    function [pdfH] = funH(hMK)
        pdfH = 2.39 * hMK.^(1.39)/(1.05)^2.39 .* exp( - (hMK/1.05).^2.39);
    end

%% ---- Conditional distribution of xiMK given hMK ----- Dag Myrhaug(2012)
    function [pdfXiH] = funXi_H(hMK,xiMK)
        
        sigmaS = - 0.15 * atan( 1.75 * (hMK - 1.2)) + 0.225; %% Eq.(5)
        sigmaXi = 1 / 4 * sigmaS; %% Eq.(10)
        [m,n] = size(hMK);
        muXi = zeros(m,n);
        
        for i = 1:1:m
            for k = 1:1:n
                if hMK(i,k) <= 1.7
                muS = 0.096 - 1.021 * hMK(i,k) + 0.558 * hMK(i,k)^2; %% Eq.(4)
                else if hMK(i,k) > 1.7
                        muS = 0.25 * atan( 4 * ( hMK(i,k) - 1.7 ) ) - 0.027; %% Eq.(4)
                    end
                end
                muXi(i,k) = - muS/2; %% Eq.(5)
               
            end
            
        end
        
        %%----Elementwise operation-----
         pdfXiH = 1 ./ ( sqrt(2*pi) * sqrt(sigmaXi) .* xiMK) .* exp( - ( log(xiMK) - muXi).^2 ./ ( 2 * sigmaXi) );
       
    end

end