

clc

clear all

mu=0.504;

%%%----Integrate over xi--------
hMK = [0.5 1 1.4 2.1];
xiMK = 0.001:0.001:3.001;
for i = 1:1:length(hMK)
pdfH(i,1) = integral(@(xiMK)pdfxiMKhMK(xiMK,hMK(i),mu),0,inf);
end
%%%----Integrate over xi--------
nn = length(hMK);
kk = length(xiMK);
pdf = pdfxiMKhMK(ones(nn,1)*xiMK,hMK'*ones(1,kk),mu);
%%%----Conditional distribution f(xi|h)----
conPDF=zeros(length(hMK),length(xiMK));
for i=1:1:length(hMK)
    conPDF(i,:)=pdf(i,:)/pdfH(i,1);
end
%%%----Conditional distribution f(xi|h)----

%%%---Verify integral of conditional probability f(xi|h) goes to 1--
VCDFxi_h=zeros(length(hMK),1);

for i=1:1:length(hMK)
 VCDFxi_h(i) = trapz(xiMK,conPDF(i,:));  
end

%%%---Verify integral of conditional probability f(xi|h) goes to 1--

%%%----CDF P(xi|h)----------
CDFxi_h=zeros(length(hMK),length(xiMK)-1);

for i=1:1:length(hMK)
  for j=2:1:length(xiMK)
    CDFxi_h(i,j-1) = trapz(xiMK(1:j),conPDF(i,1:j)); 
  end
   
end


NN = (length(xiMK)-1)/2;
if mod(NN,2) ~=0
    error('myApp:cdfXi_H','Number of integration points should be odd');
end
cdfXiH_Sp = zeros(length(hMK),NN);
dxiMK = xiMK(2) - xiMK(1);
for i = 1:1:length(hMK)
  for j = 1:1:NN
    cdfXiH_Sp(i,j) = dxiMK/3 * (conPDF(i,1) +...
        conPDF(i,2*j+1) + 2*sum(conPDF(i,3:2:2*j-1)) +...
        4*sum(conPDF(i,2:2:2*j)) );    
%     cdfXiSp(i,mm) = dxiMK/3 * (pdfXi(1,1) + pdfXi(2*i+1,1) + ...
%         2*sum(pdfXi(3:2:2*i-1)) + 4*sum(pdfXi(2:2:2*i,1)) );
  end
end
%%%----CDF P(xi|h)----------


%%----Postprocess-------
figure(1);
colorSig=['b','r','g','k'];
AA=[0.5 1 1.4 2.1];
row=zeros(length(AA),1);
col=zeros(length(AA),1);
NN=1;

for i=1:1:length(AA)
    
   %%%---It is impossible of using find(h==1.4) to find corresponding
   %%%---index. Maybe it is caused by round-off error in computer storage--
   %%%---Therefore, an alternative is in use.
    [rowA,colA]=find(abs(hMK-AA(1,i))<1e-6);
   %%%---It is impossible of using find(h==1.4) to find corresponding
   %%%---index. Maybe it is caused by round-off error in computer storage--
   %%%---Therefore, an alternative is in use.
    if ~isempty(rowA) & ~isempty(colA)
    row(NN)=rowA;
    col(NN)=colA;
    NN=NN+1;
    end
end

charNum=num2str(hMK(1,col(1:NN-1))');
cellNum=cellstr(charNum);
headCell=cell(length(col(1:NN-1)),1);
hpNum=zeros(length(col(1:NN-1)),1);
for i=1:1:length(col(1:NN-1))
x=log(xiMK(2:end));
y=log(-log(1-CDFxi_h(col(i),:)));
headCell{i,1}='$\hat{h}_{MK}$ = ';

hpNum(i,1)=plot(x,y,'Color',colorSig(i),'LineWidth',2);
hold on;
end
strLeg=strcat(headCell,cellNum);

xlim([0.3 10]);
xValue=[0.3 0.5 0.7 1 1.2 1.5 2 2.5 3 4 4.5 5 5.5];
xCor=log(xValue);
xStr=cellstr(num2str(xValue'));
yValue=[0.001 0.01 0.05 0.1 0.2 0.6 0.9  0.999  0.99999];
yCor=log(-log(1-(yValue)));
yStr=cellstr(num2str(yValue',12)); %% set precison for displaying sufficient digits in ylabel

set(gca,'XTick',xCor);
set(gca,'YTick',yCor);
set(gca,'XTickLabel',xStr);
set(gca,'YTickLabel',yStr);
set(gca,'FontSize',26);
set(gca,'XLim',[log(0.3),log(3)]);
axis([log(0.3) log(3) log(-log(1-0.001)) log(-log(1-0.99999))]);

hpLeg=legend(hpNum,strLeg,'Location','SouthEast','FontSize',12,'FontWeight','bold');
set(hpLeg,'Interpreter','Latex','FontSize',26);
xlabel('$$\hat{h}_{MK}$$','interpreter','latex','FontSize',26);
ylabel('P($\hat{\xi}_{MK} |\hat{h}_{MK}$)','interpreter','latex','FontSize',26);
title('Commulative Distribution $ P(\hat{\xi}_{MK}|\hat{h}_{MK})$ versus $\hat{h}_{MK}$ in Weibull-scale','Interpreter',...
    'Latex','FontSize',26);
%%----Postprocess-------

