

clc
clear all
mu=0.504;
LvIntCC=1/2*(1+(1+mu^2)^(-0.5));
%%---Transform to dimensionless quantities used in MK84----
K = 1;
Hs=7.5;
hrms=0.714*Hs;
Hcr = [1 1.4].*hrms;
%%---Parameters---------
Tp=9.5;
Tz=Tp/1.22;
g=9.81;
Sm=Hs/(g*Tz^2/(2*pi));
mslope=0.1;
xirms=mslope/sqrt(0.7*Sm);
%%---Parameters---------
 Rstart = 0.0005;
 Rend = 250.0005;
 JJ = 19;
 %%----odd number of elements in R-----
 R = Rstart: (Rend - Rstart)/(2^(JJ-1)) :Rend; %% Run-up
 
 NN = length(Hcr);
 KK = length(R);
 pdf = pdfRH(K,ones(NN,1)*R,Hcr'*ones(1,KK),mu,xirms,hrms);

%%%----Integrate over R--------
pdfH = zeros(NN,1);
     for i=1:1:NN
       
        pdfH(i,1) = integral(@(R)pdfRH(K,R,Hcr(i),mu,xirms,hrms),0,inf);
      
    end

%%%----Integrate over R--------


%%%----Conditional distribution f(R|h)----
conPDF=zeros(NN,KK);
for i=1:1:NN
    conPDF(i,:)=pdf(i,:)/pdfH(i,1);
end
%%%----Conditional distribution f(R|h)----


%%---Expected value E(R|hMK)-------
RsExpSp=zeros(2,1);
RsExpRom = zeros(2,1);
dR = (Rend - Rstart)./(2^(JJ-1));
for i=1:1:2
    %%-----Simpson Method-----
    RsExpSp(i,1)= dR/3 * ( R(1) * conPDF(i,1) + R(end) * conPDF(i,end) + ...
        4 * sum( R(2:2:end-1).* conPDF(i,2:2:end-1) ) + 2*sum( R(3:2:end-2) .*...
        conPDF(i,3:2:end-2) ) );
    %%-----Romberg Method------
    RsExpRom(i,1) = RombergInt( R.*conPDF(i,:),R(1),R(end) );
end
%%---Expected value E(R|hMK)-------

%%--------Find index as R=RsExp-----
colRs=zeros(NN,1);
for i=1:1:NN
 [~,colRs(i,1)]=min(abs(R-RsExpSp(i,1)));   
end
%%--------Find index as R=RsExp------

%%%---Verify integral of conditional probability f(R|h) goes to 1--
VCDFxi_h=zeros(NN,1);
for i=1:1:NN
   
        VCDFxi_h(i)=trapz(R,conPDF(i,:));
end
%%%---Verify integral of conditional probability f(R|h) goes to 1--

%%%----CDF P(R|h)----------
CDFxi_h=zeros(NN,length(R)-1);

for i=1:1:NN
    for j=2:1:length(R)      
        CDFxi_h(i,j-1)=trapz(R(1:j),conPDF(i,1:j));      
    end
    
end

for i =1:1:NN
CDFsp(i,1) = CDFxi_h(i,colRs(i,1)-1);
end


%%%----Postprocess--------------
figure(1);
h_MK = [1 1.4];
colorSig=['r','b','g','k'];
charNum=num2str(h_MK');
cellNum=cellstr(charNum);
headCell=cell(length(colRs),1);
hpNum=zeros(length(colRs),1);
for i=1:1:length(colRs)
    x=R(2:end);
    y=CDFxi_h(i,:);
    headCell{i,1}='$h_{MK}$ = ';
    
    hpNum(i,1)=plot(x,y,'Color',colorSig(i),'LineWidth',2);
    hold on;
end

for i=1:1:length(colRs)

    xR=R(colRs(i,1));
    yR=CDFxi_h(i,colRs(i,1)-1);
    plot(xR,yR,'Marker','+','MarkerEdgeColor',colorSig(i),'MarkerSize',16);
    hold on;
end

strLeg=strcat(headCell,cellNum);
grid on;
hpLeg=legend(hpNum,strLeg,'Location','Best','FontSize',12,'FontWeight','bold');
set(hpLeg,'Interpreter','Latex');
xlabel('Run up [m]','interpreter','latex','FontSize',14);
ylabel('Cummulative Distribution ','interpreter','latex','FontSize',14);
title('Run-up distribution for Hs=7.5 m - Tp=9.5 s - m=0.1','Interpreter',...
    'Latex','FontSize',14);
%%%----Postprocess--------------
