
clc

clear all

mu=[0.1 0.3 0.504 0.6];

%%---Transform to dimensionless quantities used in MK84----
xiMK=0.001:0.001:200.001;
hMK=0.01:0.01:2.5;
hpNum=zeros(length(mu)+1,1);
colorSig=['r','b','g','m','c'];
figure(1);
nn = length(xiMK);
kk = length(hMK);
Exi_h=zeros(length(hMK),length(mu));
for mm=1:1:length(mu)

pdf = pdfxiMKhMK(ones(kk,1)*xiMK,hMK'*ones(1,nn),mu(mm));

%%%----Integrate over xi--------
pdfH=zeros(length(hMK),1);
for i=1:1:length(hMK)
 pdfH(i,1) =  integral(@(xiMK)pdfxiMKhMK(xiMK,hMK(i),mu(mm)),0,inf);
end
%%%----Integrate over xi--------

%%%----Conditional distribution f(xi|h)----
conPDF=zeros(length(hMK),length(xiMK));
for i=1:1:length(hMK)
    conPDF(i,:)=pdf(i,:)/pdfH(i,1);
end
%%%----Conditional distribution f(xi|h)----

%%%---Verify integral of conditional probability f(xi|h) goes to 1--
CDFxi_h=zeros(length(hMK),1);

for i=1:1:length(hMK)
   
    CDFxi_h(i)=trapz(xiMK,conPDF(i,:));
   
end
%%%---Verify integral of conditional probability f(xi|h) goes to 1--

%%%---Expected Value E(xi|h)------

dxiMK = xiMK(2) - xiMK(1);
for i=1:1:length(hMK)
    Exi_h(i)= dxiMK/3 * ( xiMK(1)*conPDF(i,1) + xiMK(end)*conPDF(i,end) +...
        2*sum(xiMK(3:2:end-2).*conPDF(i,3:2:end-2)) + 4*sum(xiMK(2:2:end-1).*conPDF(i,2:2:end-1)) ); 
end
%%%---Expected Value E(xi|h)------

%%-----Variance sigma(xi|h)-------
 Exi_h2= dxiMK/3 * ( (xiMK(1).^2) * conPDF(i,1) + (xiMK(end).^2) * conPDF(i,end) +...
        2*sum( (xiMK(3:2:end-2).^2).*conPDF(i,3:2:end-2)) + 4*sum( (xiMK(2:2:end-1).^2).*conPDF(i,2:2:end-1)) ); 
 sigma (i)= sqrt(Exi_h2 - Exi_h(i)^2);
%%-----Variance sigma(xi|h)-------
%%%---plot a part of Expected Value---
[row,col]=find(mod(hMK,0.05)==0);
y=Exi_h(col,1);
x=hMK(1,col);
hpNum(mm,1)=plot(x,y,'-','Color',colorSig(mm),'Marker','.','MarkerSize',14);
hold on;
%%%---plot a part of Expected Value---
end

% clc
% clear all

h=0.1:0.1:9;
mus=zeros(length(h),1);
vars=zeros(length(h),1);
for i=1:1:length(h)
[mus(i),vars(i)]=ExpUsSigs(h(i));
end

uEta=-mus./2;
varEta=vars./4;
sigEta=sqrt(varEta);

ExpEtaH=exp(uEta+1/2*varEta);
hpNum(end)=plot(h,ExpEtaH,'Color','r','Marker','^');


headCell=cell(length(mu),1);
for i=1:1:length(mu)
    headCell{i,1}='$\upsilon=$';
end
charNum=num2str(mu');
strNum=cellstr(charNum);
strLeg=strcat(headCell,strNum);
strLeg = vertcat(strLeg,'MF12');
hleg=legend(hpNum,strLeg,'Location','NorthEast');
set(hleg,'Interpreter','Latex');






%%**** Necessary to alter row vector into column vector due to cellstr
% xStr=cellstr(num2str(Eta(2:end)'));
xCor=[0:0.25:2.5];
set(gca,'XTick',xCor);
xlim=[0 2.5];
set(gca,'XLim',xlim);
set(gca,'FontSize',26);
xlabel('$$\hat{h}_{MK}$$','interpreter','latex','FontSize',26);
ylabel('E($\hat{\xi}_{MK} | \hat{h}_{MK}$)','interpreter','latex','FontSize',26);
title('Expected value of $ \hat{\xi}_{MK}$ given $\hat{h}_{MK}$ by using dimensionless quantities in MK84','Interpreter',...
    'Latex','FontSize',26);
