
clc
clear all
close all

%%%----Bandwidth Parameter---
upsilon=0.504;
%%%----Bandwidth Parameter---

%%% Here mu means slope;
mu=[0.3];
%%% Here mu means slope;
hpNum=zeros(length(mu),1);
colorSig=['b','r','g','k','c','m','y'];



%%---Sm is one of the sea state parameters
Hs=7.5;  %% Significant wave height
Tp=9.5;  %% peak period
Tz=Tp/1.22; %% zero crossing period Myrhaug(2012) Page 243
g=9.81;  %% gravity acceleration
Sm=Hs/((g*Tz^2)/(2*pi));
xirms = mu/sqrt( 0.7*Sm );
hrms = 0.714 * Hs;

%%---Sm is one of the sea state parameters

%%----hMK and xiMk are wave components parameters
h=0.005:0.005:18;
xi=0.005:0.005:7;
%%----hMK and xiMk are wave components parameters
NN = length(xi);
KK = length(h);


figure(1);
% xiMK = ones(KK,1)*xi./xirms;
% hMK = h' * ones(1,NN)./hrms;
 xiM = ones(KK,1)*xi;
 hM = h' * ones(1,NN);

%         pdf = 1/xirms * 1/hrms * pdfxiMKhMK(xiMK,hMK,upsilon);
pdf = pdfXiH(xiM,hM,upsilon,xirms,hrms);
        v=10.^[-4:1:-1];
        [~,hpNum]=contour(xi,h,pdf,v,'LineWidth',2);
        
         hold on;
        maxValue=max(max(pdf,[],1));
        [row,col]=find(pdf==maxValue);
        
        plot(xi(col),h(row),'Marker','x',...
            'MarkerEdgeColor','k',...
            'MarkerSize',14,...
            'LineWidth',2);
        cdf = integral2(@(xi,H)pdfXiH(xi,H,upsilon,xirms,hrms),0,inf,0,inf);
        
        %%%----Integrate over h-------
        
        
        
        xiSp=0.001:0.005:0.5;
        cdfSp=FunBreakerProp(xiSp,upsilon,xirms,hrms);
        
        xiPl=0.5:0.005:3; 
        cdfPl=FunBreakerProp(xiPl,upsilon,xirms,hrms);
        
        xiCo=3:0.005:3.5;
        cdfCo=FunBreakerProp(xiCo,upsilon,xirms,hrms);
        
        xiSu=3.5:0.005:300;
        cdfSu=FunBreakerProp(xiSu,upsilon,xirms,hrms);
        %%----Integrate over whole range of h and a part of xi-----
        %%----The end intergration point of preceeding range is the same 
        %%----as the starting integration point of consequtive range for
        %%----numerical procedure, even though theoretical they are not the
        %%----same
        
        %%%---Verifty identity with direct integration of whole range
        TotInt=cdfSp+cdfPl+cdfCo+cdfSu;
        %-----dxi=0.005------
        %%----With mu=0.1 and xiSu=3.5:0.005:300; TotInt = 0.9998
        %%----With mu=0.3 and xiSu=3.5:0.005:300; TotInt = 0.9993
        %%----With mu=0.5 and xiSu=3.5:0.005:300; TotInt = 0.9988
        %%%---Verifty identity with direct integration of whole range


%%**** Necessary to alter row vector into column vector due to cellstr
headCell=cell(length(mu),1);
for i=1:1:length(mu)
    headCell{i,1}='m = ';
end


yLimit=get(gca,'ylim');
hold on;
digit=4;
textPosition=0.15*yLimit(2);
line([0 0],yLimit,'Color','m','LineWidth',2);
SpNum=100*round(cdfSp.*(10 ^ digit))./(10 ^ digit);
text(0+0.1,textPosition,0,['Spilling - ','Prob= ',num2str(SpNum),'%'],'Rotation',90,'FontWeight','demi','FontSize',30,'Color','m');

line([0.5 0.5],yLimit,'Color','r','LineWidth',2);
PlNum=100*round(cdfPl.*(10 ^ digit))./(10^digit);
text(0.5+0.1,textPosition,0,['Plunging - ','Prob= ',num2str(PlNum),'%'],'Rotation',90,'FontWeight','demi','FontSize',30,'Color','r');

line([3 3],yLimit,'Color','g','LineWidth',2);
CoNum=100*round(cdfCo.*(10 ^ digit))./(10^digit);
text(3+0.1,textPosition,0,['Collapsing - ','Prob= ',num2str(CoNum),'%'],'Rotation',90,'FontWeight','demi','FontSize',30,'Color','g');

line([3.5 3.5],yLimit,'Color','k','LineWidth',2);
SuNum=100*round((1-cdfSp-cdfPl-cdfCo).*(10 ^ digit))./(10 ^ digit);
text(3.5+0.1,textPosition,0,['Surging - ','Prob= ',num2str(SuNum),'%'],'Rotation',90,'FontWeight','demi','FontSize',30,'Color','k');


charMu=num2str(mu');
strMu=cellstr(charMu);
cellLeg=strcat(headCell,strMu);
legend(hpNum,cellLeg,'Location','NorthEast');

xlabel('$ \xi $ ','interpreter','latex','FontSize',30);
ylabel('H','interpreter','latex','FontSize',30);
%%---Ways to get multiline horizontally centered title----
title({'\makebox[4in][c]{Isocontours of the $(H,\xi)$ - joint probability density function}','\makebox[4in][c]{Hs=7.5m - Tp =9.5s - m=0.3}'},...
    'Interpreter','latex','FontName','TimesNewRoman','FontSize',30)
%%---Ways to get multiline horizontally centered title----

xValue=(0:0.5:7);
xCor=xValue;
xStr=cellstr(num2str(xValue'));
yValue=0:2:18;
yCor=yValue;
yStr=cellstr(num2str(yValue',12)); %% set precison for displaying sufficient digits in ylabel
xlim([-0.1 7]);
set(gca,'XTick',xCor);
set(gca,'YTick',yCor);
set(gca,'XTickLabel',xStr);
set(gca,'YTickLabel',yStr);
set(gca,'FontSize',30);
